@@ -59,8 +59,8 @@ class FileWriters:
         :param mode: 读写模式，如'wb', 'rb+'
         """
         self.workers = workers
-        self.handles = [open(filename, mode) for i in range(workers)]
-        self.handles_lock = [threading.Lock() for i in range(workers)]
+        self.handles = [open(filename, mode) for _ in range(workers)]
+        self.handles_lock = [threading.Lock() for _ in range(workers)]
         self.pool = ThreadPoolExecutor(max_workers=workers)
         self.job_q = []
         self.cur_handle = 0
@@ -92,8 +92,10 @@ class FileWriters:
         :param index: 起始位置
         :return:
         """
-        self.job_q.append(self.pool.submit(self._write, self.cur_handle, content, index))
-        self.cur_handle = (self.cur_handle+1) % self.workers
+        self.job_q.append(
+            self.pool.submit(self._write, self.cur_handle, content, index)
+        )
+        self.cur_handle = (self.cur_handle + 1) % self.workers
 
     def __del__(self):
         """
@@ -105,3 +107,28 @@ class FileWriters:
         """
         self.wait()
         self.pool.shutdown()
+
+
+class MemWriter:
+    import heapq
+
+    def __init__(self):
+        """
+        线程安全的写内存。
+        """
+        self.mem_blocks = []
+
+    def new_job(self, content: bytes, index: int):
+        # 将内容写入内存
+        self.heapq.heappush(self.mem_blocks, (index, content))
+
+    @property
+    def content(self):
+        # 获取内存内容
+        res = b""
+        while self.mem_blocks:
+            res += self.heapq.heappop(self.mem_blocks)[1]
+        return res
+
+    def wait(self):
+        pass
