@@ -6,7 +6,7 @@ Call various system tools
 """
 import QuickStart_Rhy.Wrapper as _wrapper
 
-miss_file = ['.DS_Store']
+miss_file = [".DS_Store"]
 
 
 def __latest_filename(name):
@@ -19,10 +19,10 @@ def __latest_filename(name):
         if os.path.exists(name):
             os.chdir(rec)
             return cur + dir_char + name
-        os.chdir('..')
+        os.chdir("..")
         cur = os.getcwd()
     os.chdir(rec)
-    return ''
+    return ""
 
 
 def top():
@@ -34,15 +34,19 @@ def top():
     :return: None
     """
     from . import dir_char
-    if dir_char == '\\':
+
+    if dir_char == "\\":
         from .SystemTools.Monitor import top
+
         top()
     else:
         import sys
-        sys.argv = ['bpytop'] + sys.argv[2:]
+
+        sys.argv = ["bpytop"] + sys.argv[2:]
 
         from . import requirePackage
-        requirePackage('bpytop', 'main')()
+
+        requirePackage("bpytop", "main")()
 
 
 def clear_mem():
@@ -54,6 +58,7 @@ def clear_mem():
     :return: None
     """
     from .SystemTools import clear_mem
+
     clear_mem()
 
 
@@ -64,25 +69,35 @@ def go_github():
     Automatically recognize the address in the current folder .git/config and open it through a browser
     """
     import os
-    from . import qs_default_console, qs_error_string, user_lang, open_url, requirePackage
+    from . import (
+        qs_default_console,
+        qs_error_string,
+        user_lang,
+        open_url,
+        requirePackage,
+    )
 
-    config_path = __latest_filename('.git/config')
+    config_path = __latest_filename(".git/config")
     if not os.path.exists(config_path):
-        qs_default_console.print(qs_error_string, 'No a git dictionary' if user_lang != 'zh' else '不是 git 文件夹')
+        qs_default_console.print(
+            qs_error_string,
+            "No a git dictionary" if user_lang != "zh" else "不是 git 文件夹",
+        )
         return
-    config = requirePackage('configparser', 'ConfigParser')()
+    config = requirePackage("configparser", "ConfigParser")()
     config.read(filenames=config_path)
     url_ls = []
     for section in config.sections():
-        if section.startswith('remote'):
-            url_ls.append(config[section]['url'].replace('.git', ''))
+        if section.startswith("remote"):
+            url_ls.append(config[section]["url"].replace(".git", ""))
     open_url(url_ls)
 
 
 @_wrapper.mkCompressPackageWrap
-def _mktar(file_path: str = ''):
+def _mktar(file_path: str = ""):
     from .SystemTools.Compress import Tar
-    return Tar(file_path + '.tar.gz', 'w')
+
+    return Tar(file_path + ".tar.gz", "w")
 
 
 def mktar():
@@ -97,8 +112,9 @@ def mktar():
 
 
 @_wrapper.unCompressPackageWrap
-def _untar(file_path: str = ''):
+def _untar(file_path: str = ""):
     from .SystemTools.Compress import Tar
+
     return Tar(file_path)
 
 
@@ -114,9 +130,10 @@ def untar():
 
 
 @_wrapper.mkCompressPackageWrap
-def _mkzip(file_path: str = ''):
+def _mkzip(file_path: str = ""):
     from .SystemTools.Compress import Zip
-    return Zip(file_path + '.zip', 'w')
+
+    return Zip(file_path + ".zip", "w")
 
 
 def mkzip():
@@ -131,9 +148,10 @@ def mkzip():
 
 
 @_wrapper.unCompressPackageWrap
-def _unzip(file_path: str = ''):
+def _unzip(file_path: str = ""):
     from .SystemTools.Compress import Zip
-    return Zip(file_path, 'r')
+
+    return Zip(file_path, "r")
 
 
 def unzip():
@@ -148,8 +166,9 @@ def unzip():
 
 
 @_wrapper.unCompressPackageWrap
-def _unrar(file_path: str = ''):
+def _unrar(file_path: str = ""):
     from .SystemTools.Compress import Rar
+
     return Rar(file_path)
 
 
@@ -165,9 +184,10 @@ def unrar():
 
 
 @_wrapper.mkCompressPackageWrap
-def _mk7z(file_path: str = ''):
+def _mk7z(file_path: str = ""):
     from .SystemTools.Compress import SevenZip
-    return SevenZip(file_path + '.7z', 'w')
+
+    return SevenZip(file_path + ".7z", "w")
 
 
 def mk7z():
@@ -182,8 +202,9 @@ def mk7z():
 
 
 @_wrapper.unCompressPackageWrap
-def _un7z(file_path: str = ''):
+def _un7z(file_path: str = ""):
     from .SystemTools.Compress import SevenZip
+
     return SevenZip(file_path)
 
 
@@ -198,7 +219,7 @@ def un7z():
     return _un7z()
 
 
-@_wrapper.HashWrapper('md5')
+@_wrapper.HashWrapper("md5")
 def md5():
     """
     获取文件md5值
@@ -206,7 +227,7 @@ def md5():
     """
 
 
-@_wrapper.HashWrapper('sha1')
+@_wrapper.HashWrapper("sha1")
 def sha1():
     """
     获取文件sha1值
@@ -214,7 +235,7 @@ def sha1():
     """
 
 
-@_wrapper.HashWrapper('sha256')
+@_wrapper.HashWrapper("sha256")
 def sha256():
     """
     获取文件sha256值
@@ -222,7 +243,7 @@ def sha256():
     """
 
 
-@_wrapper.HashWrapper('sha512')
+@_wrapper.HashWrapper("sha512")
 def sha512():
     """
     获取文件sha512值
@@ -239,18 +260,22 @@ def diff_dir():
     from .SystemTools.Diff import DictionaryFiles
     import sys
 
-    if '-h' in sys.argv:
-        qs_default_console.print(qs_info_string, 'Usage: qs diff <dir1> <dir2> [-x <name or regex pattern>]')
+    if "-h" in sys.argv:
+        qs_default_console.print(
+            qs_info_string, "Usage: qs diff <dir1> <dir2> [-x <name or regex pattern>]"
+        )
 
     d1, d2 = sys.argv[2:4]
-    apply_ignore = sys.argv[sys.argv.index('-x') + 1:] if '-x' in sys.argv else None
+    apply_ignore = sys.argv[sys.argv.index("-x") + 1 :] if "-x" in sys.argv else None
     d1 = DictionaryFiles(d1, apply_ignore)
     d2 = DictionaryFiles(d2, apply_ignore)
 
     if not (d1.available and d2.available):
         return
 
-    with qs_default_console.status('Generating diff result..' if user_lang != 'zh' else '生成对比结果中..'):
+    with qs_default_console.status(
+        "Generating diff result.." if user_lang != "zh" else "生成对比结果中.."
+    ):
         from .SystemTools.Diff import DiffFilesToStructHtml
 
         DiffFilesToStructHtml(d1, d2).generate()
@@ -279,16 +304,20 @@ def unmount_dmg():
     disks = DMG()
     _ls = disks.get_disk_list()[2:]
     if not _ls:
-        return qs_default_console.print(qs_info_string, 'No DMG disk found' if user_lang != 'zh' else '没有找到 dmg 磁盘')
-    table = qs_default_table(['Disk', 'Type', 'Size'])
+        return qs_default_console.print(
+            qs_info_string, "No DMG disk found" if user_lang != "zh" else "没有找到 dmg 磁盘"
+        )
+    table = qs_default_table(["Disk", "Type", "Size"])
     for disk in _ls:
-        table.add_row(disk['path'], disk['type'], disk['size'])
-    qs_default_console.print(table, justify='center')
-    disk_path = prompt({
-        'type': 'list',
-        'message': 'Select a disk to umount' if user_lang != 'zh' else '选择要卸载的磁盘',
-        'choices': [disk['path'] for disk in _ls],
-        'name': 'disk',
-        'default': _ls[0]['path']
-    })['disk']
+        table.add_row(disk["path"], disk["type"], disk["size"])
+    qs_default_console.print(table, justify="center")
+    disk_path = prompt(
+        {
+            "type": "list",
+            "message": "Select a disk to umount" if user_lang != "zh" else "选择要卸载的磁盘",
+            "choices": [disk["path"] for disk in _ls],
+            "name": "disk",
+            "default": _ls[0]["path"],
+        }
+    )["disk"]
     disks.unmount(disk_path)
